SumupPayment class

Payment object.

Constructors

SumupPayment({String? title, required double total, String currency = 'EUR', double tip = .0, bool tipOnCardReader = false, bool skipSuccessScreen = false, bool skipFailureScreen = false, String? foreignTransactionId, int saleItemsCount = 0, String? customerEmail, String? customerPhone, CardType? cardType})

Properties

cardType ↔ CardType?
Optional card type that in some country is required.
getter/setter pair
currency ↔ String
Payment currency, defaults to EUR.
getter/setter pair
customerEmail ↔ String?
Optional customer email useful to autofill email field on transaction successful screen.
getter/setter pair
customerPhone ↔ String?
Optional customer phone number useful to autofill phone field on transaction successful screen.
getter/setter pair
foreignTransactionId ↔ String?
An identifier associated with the transaction that can be used to retrieve details related to the transaction.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleItemsCount ↔ int
Number of items included in this payment, visible in SumUp checkout screen.
getter/setter pair
skipFailureScreen ↔ bool
Skips failure screen. Useful if you want to provide your own failure message.
getter/setter pair
skipSuccessScreen ↔ bool
Skips success screen. Useful if you want to provide your own success message.
getter/setter pair
tip ↔ double
Optional tip, defaults to 0. If tip is grater than 0, tipOnCardReader must be false.
getter/setter pair
tipOnCardReader ↔ bool
Shows tip on card reader if card reader supports it. If tipOnCardReader is true, tip must be 0.
getter/setter pair
title ↔ String?
Optional payment title, will be visible on merchant transaction history.
getter/setter pair
total ↔ double
Total payment amount.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited