SumupPluginCheckoutResponse class

Checkout response object.

Contains all the transaction informations. Some fields are available for Android only.

Constructors

SumupPluginCheckoutResponse({bool? success, String? transactionCode, String? cardLastDigits, String? cardType, bool? receiptSent, String? foreignTransactionId, double? amount, double? vatAmount, double? tipAmount, String? currency, String? paymentType, String? entryMode, int? installments, bool? userDismissedSuccessScreen, String? errors, List<SumupProduct>? products, String? merchantCode, String? cardScheme})
SumupPluginCheckoutResponse.fromMap(Map response)

Properties

amount double?
Total amount including tip and VAT
getter/setter pair
cardLastDigits String?
getter/setter pair
cardScheme String?
Card scheme (e.g. VISA, MASTERCARD) (Android Tap-to-Pay).
getter/setter pair
cardType String?
getter/setter pair
currency String?
getter/setter pair
entryMode String?
getter/setter pair
errors String?
Error message when success is false (e.g. "Transaction canceled", "Tap-to-Pay init failed").
getter/setter pair
foreignTransactionId String?
Android only
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
installments int?
getter/setter pair
merchantCode String?
Merchant code associated with the transaction (Android Tap-to-Pay).
getter/setter pair
paymentType String?
getter/setter pair
products List<SumupProduct>?
Products included in the transaction.
getter/setter pair
receiptSent bool?
Android only
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool?
Transaction's outcome
getter/setter pair
tipAmount double?
getter/setter pair
transactionCode String?
getter/setter pair
userDismissedSuccessScreen bool?
True when the user closed the success screen (e.g. back arrow) instead of Done/Send receipt.
getter/setter pair
vatAmount double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited