userDismissedSuccessScreen property
True when the user closed the success screen (e.g. back arrow) instead of Done/Send receipt.
Implementation
bool? userDismissedSuccessScreen;
True when the user closed the success screen (e.g. back arrow) instead of Done/Send receipt.
bool? userDismissedSuccessScreen;