TapToPayAvailabilityResult class

Result of checking Tap-to-Pay availability.

Constructors

TapToPayAvailabilityResult({required bool isAvailable, required bool isActivated, String? error})
TapToPayAvailabilityResult.fromMap(Map map)
factory

Properties

error String?
Error message from the native SDK, if availability check failed (e.g. init failed, attestation).
final
hashCode int
The hash code for this object.
no setterinherited
isActivated bool
Whether Tap-to-Pay has been activated (e.g. on iOS, activation completed).
final
isAvailable bool
Whether Tap-to-Pay is available for the current merchant/device.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited