SumupProduct class

A product item included in a transaction.

Available on iOS and Android (card reader checkout only).

Constructors

SumupProduct({String? name, double? price, int? quantity})
SumupProduct.fromMap(Map map)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
Product name.
final
price double?
Product unit price.
final
quantity int?
Product quantity.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited